@@ -10,18 +10,14 @@ class Worker(object):
     def run(self, cls, *args, **kargs):
         ins = cls(*args, **kargs)
         while 1:
-            print 0, time.time()
             task =  self.tq.GET_TASK()
-            print 1, time.time()
             key, method, args = task
             func = getattr(ins, method, None)
             if func:
-                # try:
-                print 2, time.time()
-                result = func(*args)
-                print 3, time.time()
-                # except Exception, e:
-                #   result = str(e)
+                try:
+                    result = func(*args)
+                except Exception, e:
+                    result = str(e)
             else:
                 result = "No Such Method!"
             self.tq.PUT_RESULT(key, result)
