@@ -1,13 +1,9 @@
 from gevent import monkey; monkey.patch_all()
-from gevent.pool import Pool
 import gevent
 import inspect
 from ..config import config
 
 
-pool = Pool(config.num_greenlet)
-
-
 def import_globals():
     frame, outerframe = [x[0] for x in inspect.getouterframes(inspect.currentframe())[1:3]]
     frame.f_globals.update(outerframe.f_globals)
@@ -18,7 +14,6 @@ def pmap(f, l):
         lets.append(gevent.spawn(f, i))
     gevent.joinall(lets)
     return [i.value for i in lets]
-    # return pool.map(f, l)
 
 def export(ls):
     frame = inspect.getouterframes(inspect.currentframe())[1][0]
